pub struct PoEProof {
pub x: BigInt,
pub u: BinaryQF,
pub w: BinaryQF,
pub Q: BinaryQF,
}Expand description
This is a proof of exponentiation as given in https://eprint.iacr.org/2019/1229.pdf section 3.4 The prover can efficiently convince a verifier that a large exponentiation in a group of unknown order was done correctly. statement is (x,u,w), verifier accept if w = u^x.
Fields
x: BigIntu: BinaryQFw: BinaryQFQ: BinaryQFImplementations